Transaction

Struct Transaction 

pub struct Transaction<Mode> {
    inner: Transaction<'static, Db>,
    metrics: TransactionMetricsGuard<Mode>,
}
An atomic SQL transaction.

Fields

inner: Transaction<'static, Db>metrics: TransactionMetricsGuard<Mode>

Implementations

Source

impl<Mode> Transaction<Mode>
where Mode: TransactionMode,

async fn load_namespaces<Types>( &mut self, height: u64, payload_size: u64, ) -> QueryResult<NamespaceMap<Types>>
where Types: NodeType, Header<Types>: QueryableHeader<Types>, Payload<Types>: QueryablePayload<Types>,

Source

impl<Mode> Transaction<Mode>
where Mode: TransactionMode,

async fn sync_status_ranges( &mut self, table: &str, indicator_column: &str, start: usize, end: usize, ) -> QueryResult<ResourceSyncStatus>

Characterize consecutive ranges of objects in the given height-indexed table by status.

This function will find all ranges in [0, block_height). If pruned_height is specified, an initial range will be created with bounds [0, pruned_height] and status SyncStatus::Pruned. Then only the range [pruned_height + 1, block_height) will actually be searched.

The search process uses an indexed outer self-join on table, which requires traversing the table twice. Thus, it can be fairly expensive on large tables, but it is still linear in the size of the table.

The value of indicator_column in the outer join results is used to check for missing objects (indicated by a NULL value). If indicator_column is a NOT NULL column, such as height, then this function will only consider objects missing if there is no corresponding row in the database at all. However, indicator_column may also be a nullable column (such as payload.data, in which case objects are treated as missing if there is no corresponding row or if there is a row but it has an explicit NULL value for indicator_column).

Source

impl<Mode: TransactionMode> Transaction<Mode>

async fn time_window<Types: NodeType>( &mut self, start: u64, end: u64, limit: usize, ) -> QueryResult<TimeWindowQueryData<Header<Types>>>

Source

impl<Mode: TransactionMode> Transaction<Mode>

async fn snapshot_info<Types, State, const ARITY: usize>( &mut self, snapshot: Snapshot<Types, State, ARITY>, ) -> QueryResult<(i64, State::Commit)>
where Types: NodeType, State: MerklizedState<Types, ARITY>,

Get information identifying a Snapshot.

If the given snapshot is known to the database, this function returns

  • The block height at which the snapshot was created
  • A digest of the Merkle commitment to the snapshotted state
Source

impl<Mode> Transaction<Mode>

pub async fn load_header<Types: NodeType>( &mut self, id: impl Into<BlockId<Types>> + Send, ) -> QueryResult<Header<Types>>

Load a header from storage.

This function is similar to AvailabilityStorage::get_header, but

  • does not require the QueryablePayload<Types> bound that that trait impl does
  • makes it easier to specify types since the type parameter is on the function and not on a trait impl
  • allows type conversions for the id parameter

This more ergonomic interface is useful as loading headers is important for many SQL storage functions, not just the AvailabilityStorage interface.

Source

impl<Mode: TransactionMode> Transaction<Mode>

pub(super) async fn new(pool: &Pool<Db>, metrics: PoolMetrics) -> Result<Self>

Source

impl Transaction<Write>

Low-level, general database queries and mutation.

pub async fn upsert<'p, const N: usize, R>( &mut self, table: &str, columns: [&str; N], pk: impl IntoIterator<Item = &str>, rows: R, ) -> Result<()>
where R: IntoIterator, R::Item: 'p + FixedLengthParams<'p, N>,

Source

impl Transaction<Write>

Query service specific mutations.

pub(super) async fn delete_batch( &mut self, state_tables: Vec<String>, height: u64, ) -> Result<()>

Delete a batch of data for pruning.

pub(crate) async fn save_pruned_height(&mut self, height: u64) -> Result<()>

Record the height of the latest pruned header.